<?php

namespace Litecms\Pep\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Pep\Models\Pep;


class PepAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Pep $pep, array $request = [])
    {
        $this->model = $pep;

        $function = Str::camel($action);
        event('litecms.pep.pep.action.' . $action . 'ing', [$pep]);
        $data =  $this->$function($pep, $request);
        event('litecms.pep.pep.action.' . $action . 'ed', [$pep]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Pep $pep, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $pep = $pep->create($attributes);
        return $pep;
    }

    public function update(Pep $pep, array $request)
    {
        $attributes = $request;
        $pep->update($attributes);
        return $pep;
    }

    public function destroy(Pep $pep, array $request)
    {
        $pep->delete();
        return $pep;
    }

    public function copy(Pep $pep, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $pep = $pep->replicate();
            $pep->created_at = Carbon::now();
            $pep->save();
            return $pep;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $pep->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $pep;
    }


}
