<?php

namespace Litecms\Pep\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Pep\Actions\PepAction;
use Litecms\Pep\Http\Requests\PepActionRequest;
use Litecms\Pep\Http\Resources\PepResource;
use Litecms\Pep\Models\Pep;

/**
 * Admin web controller class.
 */
class PepActionController extends BaseController
{

    /**
     * Action controller function for pep.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PepActionRequest $request, Pep $pep, $action)
    {
        try {
            $request = $request->all();
            $pep = PepAction::run($action, $pep, $request);

            $data = new PepResource($pep);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('pep::pep.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('pep/pep/' . $pep->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pep/pep/' . $pep->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
