<?php

namespace Litecms\Pep\Http\Controllers;

use Exception;
use Litecms\Pep\Actions\PepWorkflow;
use Litecms\Pep\Http\Requests\PepWorkflowRequest;
use Litecms\Pep\Http\Resources\PepResource;
use Litecms\Pep\Models\Pep;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class PepWorkflowController extends BaseController
{
    /**
     * Action controller function for pep.
     *
     * @param Model $pep
     * @param action next action for the pep.
     *
     * @return Response
     */
    public function __invoke(PepWorkflowRequest $request, Pep $pep, $trasition)
    {
        try {
            $request = $request->all();
            $pep = PepWorkflow::run($trasition, $pep, $request);
            $data = new PepResource($pep);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('pep::pep.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('pep/pep/' . $pep->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pep/pep/' . $pep->getRouteKey()))
                ->redirect();
        }
    }
}
