<?php

namespace Litecms\Pep\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Pep\Events\PepAction as PepActionEvent;
use Litecms\Pep\Notifications\PepAction as PepActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PepAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PepActionEvent.
     *
     * @param   PepActionEvent  $event
     * @return mixed
     */
    public function handle(PepActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $pep.
     *
     * @param   PepActionEvent  $event
     * @return void
     */
    public function create(PepActionEvent $event)
    {
        $client = $event->$pep->client;
        Notification::send($client, new PepActionNotification($event));
    }

    /**
     * Handle the PepActionEvent as a listener.
     *
     * @param   PepActionEvent  $event
     * @return mixed
     */
    public function asListener(PepActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PepActionEvent  $event
     * @return bool
     */
    private function isAllowed(PepActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
