<?php

namespace Litecms\Pep\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Pep\Events\PepWorkflow as PepWorkflowEvent;
use Litecms\Pep\Notifications\PepWorkflow as PepWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PepWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PepWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $pep is submitted.
     *
     * @param PepWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PepWorkflowEvent $event)
    {
        $client = $event->$pep->client;
        Notification::send($client, new PepWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $pep is published.
     *
     * @param PepWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PepWorkflowEvent $event)
    {
        $client = $event->$pep->client;
        Notification::send($client, new PepWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $pep is approved.
     *
     * @param PepWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PepWorkflowEvent $event)
    {
        $client = $event->$pep->client;
        Notification::send($client, new PepWorkflowNotification($event));
    }

    /**
     * Handles the $pep workflow event as a listener.
     *
     * @param PepWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PepWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
