<?php
namespace Litecms\Pep\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Pep\Events\PepAction as PepActionEvent;
use Litecms\Pep\Models\Pep;

class PepAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $pep;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param PepActionEvent $pep
     * @param string $action
     */
    public function __construct(PepActionEvent $pep, string $action)
    {
        $this->action = $action;
        $this->pep = $pep;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Pep Approved - ' . config('app.name'))
            ->view('pep::pep.email.action', ['data' => $this->pep]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
