<?php

namespace Litecms\Pep\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Pep\Peps;

class PepServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'pep');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'pep');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Litecms\Pep\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Pep\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Pep\Providers\ActionServiceProvider::class);
        $this->app->register(\Litecms\Pep\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.pep', function($app)
        {
            return $this->app->make(Pep::class);
        });
    }

    /**
     * Merges user's and pep's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.pep'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/pep.php', 'litecms.pep.pep'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.pep'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/pep')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/pep')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/pep')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
